# Tech Stack Discovery from SBOMs
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms#introduction)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms#prerequisites)
  * [Permissions](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms#permissions)
  * [Discovering and Creating IT Components](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms#discovering-and-creating-it-components)
  * [Viewing Tech Stacks](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms#viewing-tech-stacks)
  * [Adding Custom Tech Stacks Manually](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms#adding-custom-tech-stacks-manually)
  * [Technical Details](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms#technical-details)


Automatically discover tech stacks from ingested SBOMs. Add custom tech stacks manually to complete your technology portfolio.
